==> Ethna-0.1.4.tar.gz: Ethna-0.1.4/skel/app.controller.php <==
<?php
/**
 *	{$project_id}_Controller.php
 *
 *	@author		your name
 *	@package	{$project_id}
 *	@version	$Id: app.controller.php,v 1.8 2005/01/06 17:44:24 fujimoto Exp $
 */

/** ץꥱ١ǥ쥯ȥ */
define('BASE', dirname(dirname(__FILE__)));

// include_path(ץꥱǥ쥯ȥɲ)
$app = BASE . "/app";
$lib = BASE . "/lib";
ini_set('include_path', ini_get('include_path') . ":$app:$lib");


/** ץꥱ饤֥Υ󥯥롼 */
include_once('Ethna/Ethna.php');
include_once('{$project_id}_Error.php');

/**
 *	{$project_id}ץꥱΥȥ
 *
 *	@author		your name
 *	@access		public
 *	@package	{$project_id}
 */
class {$project_id}_Controller extends Ethna_Controller
{
	/**#@+
	 *	@access	private
	 */

	/**
	 *	@var	string	ץꥱID
	 */
	var	$appid = '{$application_id}';

	/**
	 *	@var	array	forward
	 */
	var $forward = array(
		/*
		 *	TODO: forward򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'index'			=> array(
		 *		'view_name'	=> '{$project_id}_View_Index',
		 *	),
		 */
	);

	/**
	 *	@var	array	action
	 */
	var $action = array(
		/*
		 *	TODO: action򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'index'		=> array(),
		 */
	);

	/**
	 *	@var	array	soap action
	 */
	var $soap_action = array(
		/*
		 *	TODO: SOAPץꥱѤaction
		 *	ҤƤ
		 *	㡧
		 *
		 *	'sample'			=> array(),
		 */
	);

	/**
	 *	@var	array		ץꥱǥ쥯ȥ
	 */
	var $directory = array(
		'action'		=> 'app/action',
		'etc'			=> 'etc',
		'filter'		=> 'app/filter',
		'locale'		=> 'locale',
		'log'			=> 'log',
		'plugins'		=> array(),
		'template'		=> 'template',
		'template_c'	=> 'tmp',
		'tmp'			=> 'tmp',
		'view'			=> 'app/view',
	);

	/**
	 *	@var	array		DB
	 */
	var	$db = array(
		''				=> DB_TYPE_RW,
	);

	/**
	 *	@var	array		ĥ
	 */
	var $ext = array(
		'php'			=> 'php',
		'tpl'			=> 'tpl',
	);

	/**
	 *	@var	array	饹
	 */
	var $class = array(
		/*
		 *	TODO: ꥯ饹饹SQL饹򥪡С饤
		 *	ϲΥ饹̾˺줺ѹƤ
		 */
		'class'			=> 'Ethna_ClassFactory',
		'backend'		=> 'Ethna_Backend',
		'config'		=> 'Ethna_Config',
		'db'			=> 'Ethna_DB',
		'error'			=> 'Ethna_ActionError',
		'form'			=> 'Ethna_ActionForm',
		'i18n'			=> 'Ethna_I18N',
		'logger'		=> 'Ethna_Logger',
		'session'		=> 'Ethna_Session',
		'sql'			=> 'Ethna_AppSQL',
		'view'			=> 'Ethna_ViewClass',
	);

	/**
	 *	@var	array		ե륿
	 */
	var $filter = array(
		/*
		 *	TODO: ե륿ѤϤˤΥ饹̾
		 *	ҤƤ
		 *
		 *	㡧
		 *
		 *	'{$project_id}_Filter_ExecutionTime',
		 */
	);

	/**
	 *	@var	array	ޥ͡
	 */
	var $manager = array(
		/*
		 *	TODO: ˥ץꥱΥޥ͡㥪֥Ȱ
		 *	ҤƤ
		 *
		 *	㡧
		 *
		 *	'um'	=> 'User',
		 */
	);

	/**
	 *	@var	array	smarty modifier
	 */
	var $smarty_modifier_plugin = array(
		/*
		 *	TODO: ˥桼smarty modifier򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_modifier_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty function
	 */
	var $smarty_function_plugin = array(
		/*
		 *	TODO: ˥桼smarty function򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_function_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty prefilter
	 */
	var $smarty_prefilter_plugin = array(
		/*
		 *	TODO: ˥桼smarty prefilter򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_prefilter_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty postfilter
	 */
	var $smarty_postfilter_plugin = array(
		/*
		 *	TODO: ˥桼smarty postfilter򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_postfilter_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty outputfilter
	 */
	var $smarty_outputfilter_plugin = array(
		/*
		 *	TODO: ˥桼smarty outputfilter򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_outputfilter_foo_bar',
		 */
	);

	/**#@-*/

	/**
	 *	ܻΥǥեȥޥꤹ
	 *
	 *	@access	protected
	 *	@param	object	Smarty	$smarty	ƥץ졼ȥ󥸥󥪥֥
	 */
	function _setDefaultTemplateEngine(&$smarty)
	{
		/*
		 *	TODO: ǥƥץ졼ȥ󥸥ν
		 *  ƤΥӥ塼˶̤ʥƥץ졼ѿꤷޤ
		 *
		 *	㡧
		 * $smarty->assign_by_ref('session_name', session_name());
		 * $smarty->assign_by_ref('session_id', session_id());
		 *
		 * // ե饰(true/false)
		 * $session =& $this->getClassFactory('session');
		 * if ($session && $this->session->isStart()) {
		 * 	$smarty->assign_by_ref('login', $session->isStart());
		 * }
		 */
	}
}
?>

==> Ethna-0.1.5.tar.gz: Ethna-0.1.5/skel/app.controller.php <==
<?php
/**
 *	{$project_id}_Controller.php
 *
 *	@author		your name
 *	@package	{$project_id}
 *	@version	$Id: app.controller.php,v 1.10 2005/03/01 14:34:42 fujimoto Exp $
 */

/** ץꥱ١ǥ쥯ȥ */
define('BASE', dirname(dirname(__FILE__)));

// include_path(ץꥱǥ쥯ȥɲ)
$app = BASE . "/app";
$lib = BASE . "/lib";
ini_set('include_path', ini_get('include_path') . PATH_SEPARATOR . implode(PATH_SEPARATOR, array($app, $lib)));


/** ץꥱ饤֥Υ󥯥롼 */
include_once('Ethna/Ethna.php');
include_once('{$project_id}_Error.php');

/**
 *	{$project_id}ץꥱΥȥ
 *
 *	@author		your name
 *	@access		public
 *	@package	{$project_id}
 */
class {$project_id}_Controller extends Ethna_Controller
{
	/**#@+
	 *	@access	private
	 */

	/**
	 *	@var	string	ץꥱID
	 */
	var	$appid = '{$application_id}';

	/**
	 *	@var	array	forward
	 */
	var $forward = array(
		/*
		 *	TODO: forward򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'index'			=> array(
		 *		'view_name'	=> '{$project_id}_View_Index',
		 *	),
		 */
	);

	/**
	 *	@var	array	action
	 */
	var $action = array(
		/*
		 *	TODO: action򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'index'		=> array(),
		 */
	);

	/**
	 *	@var	array	soap action
	 */
	var $soap_action = array(
		/*
		 *	TODO: SOAPץꥱѤaction
		 *	ҤƤ
		 *	㡧
		 *
		 *	'sample'			=> array(),
		 */
	);

	/**
	 *	@var	array		ץꥱǥ쥯ȥ
	 */
	var $directory = array(
		'action'		=> 'app/action',
		'etc'			=> 'etc',
		'filter'		=> 'app/filter',
		'locale'		=> 'locale',
		'log'			=> 'log',
		'plugins'		=> array(),
		'template'		=> 'template',
		'template_c'	=> 'tmp',
		'tmp'			=> 'tmp',
		'view'			=> 'app/view',
	);

	/**
	 *	@var	array		DB
	 */
	var	$db = array(
		''				=> DB_TYPE_RW,
	);

	/**
	 *	@var	array		ĥ
	 */
	var $ext = array(
		'php'			=> 'php',
		'tpl'			=> 'tpl',
	);

	/**
	 *	@var	array	饹
	 */
	var $class = array(
		/*
		 *	TODO: ꥯ饹饹SQL饹򥪡С饤
		 *	ϲΥ饹̾˺줺ѹƤ
		 */
		'class'			=> 'Ethna_ClassFactory',
		'backend'		=> 'Ethna_Backend',
		'config'		=> 'Ethna_Config',
		'db'			=> 'Ethna_DB',
		'error'			=> 'Ethna_ActionError',
		'form'			=> 'Ethna_ActionForm',
		'i18n'			=> 'Ethna_I18N',
		'logger'		=> 'Ethna_Logger',
		'session'		=> 'Ethna_Session',
		'sql'			=> 'Ethna_AppSQL',
		'view'			=> 'Ethna_ViewClass',
	);

	/**
	 *	@var	array		ե륿
	 */
	var $filter = array(
		/*
		 *	TODO: ե륿ѤϤˤΥ饹̾
		 *	ҤƤ
		 *
		 *	㡧
		 *
		 *	'{$project_id}_Filter_ExecutionTime',
		 */
	);

	/**
	 *	@var	array	ޥ͡
	 */
	var $manager = array(
		/*
		 *	TODO: ˥ץꥱΥޥ͡㥪֥Ȱ
		 *	ҤƤ
		 *
		 *	㡧
		 *
		 *	'um'	=> 'User',
		 */
	);

	/**
	 *	@var	array	smarty modifier
	 */
	var $smarty_modifier_plugin = array(
		/*
		 *	TODO: ˥桼smarty modifier򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_modifier_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty function
	 */
	var $smarty_function_plugin = array(
		/*
		 *	TODO: ˥桼smarty function򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_function_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty prefilter
	 */
	var $smarty_prefilter_plugin = array(
		/*
		 *	TODO: ˥桼smarty prefilter򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_prefilter_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty postfilter
	 */
	var $smarty_postfilter_plugin = array(
		/*
		 *	TODO: ˥桼smarty postfilter򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_postfilter_foo_bar',
		 */
	);

	/**
	 *	@var	array	smarty outputfilter
	 */
	var $smarty_outputfilter_plugin = array(
		/*
		 *	TODO: ˥桼smarty outputfilter򵭽ҤƤ
		 *
		 *	㡧
		 *
		 *	'smarty_outputfilter_foo_bar',
		 */
	);

	/**#@-*/

	/**
	 *	ܻΥǥեȥޥꤹ
	 *
	 *	@access	protected
	 *	@param	object	Smarty	$smarty	ƥץ졼ȥ󥸥󥪥֥
	 */
	function _setDefaultTemplateEngine(&$smarty)
	{
		/*
		 *	TODO: ǥƥץ졼ȥ󥸥ν
		 *  ƤΥӥ塼˶̤ʥƥץ졼ѿꤷޤ
		 *
		 *	㡧
		 * $smarty->assign_by_ref('session_name', session_name());
		 * $smarty->assign_by_ref('session_id', session_id());
		 *
		 * // ե饰(true/false)
		 * $session =& $this->getClassFactory('session');
		 * if ($session && $this->session->isStart()) {
		 * 	$smarty->assign_by_ref('login', $session->isStart());
		 * }
		 */
	}
}
?>
